@@ -1,18 +1,15 @@
-﻿var csomapi = require('csom-node');
+﻿var csomapi = require('csom-node'),
+    settings = require('./settings.js').settings;
 
-var settings = {
-    url: "https://contoso.sharepoint.com/",
-    username: "jdoe@contoso.onmicrosoft.com",
-    password: "password"
-};
+var webAbsoluteUrl = settings.tenantUrl + settings.webUrl;
 
-csomapi.setLoaderOptions({ url: settings.url, serverType: 'local', packages: [] });
+csomapi.setLoaderOptions({ url: webAbsoluteUrl, serverType: 'local', packages: [] });
 
 
-var authCtx = new AuthenticationContext(settings.url);
+var authCtx = new AuthenticationContext(webAbsoluteUrl);
 authCtx.acquireTokenForUser(settings.username, settings.password, function(err, data) {
 
-    var ctx = new SP.ClientContext("/");
+    var ctx = new SP.ClientContext(settings.webUrl);
     authCtx.setAuthenticationCookie(ctx); //authenticate
 
     var web = ctx.get_web();
